configurationtools
==================

.. automodule:: abjad.tools.configurationtools

.. only:: html

   Abstract classes
   ----------------

   .. autosummary::

      ~abjad.tools.configurationtools.Configuration.Configuration.Configuration

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.configurationtools.AbjadConfiguration.AbjadConfiguration.AbjadConfiguration
